@@ -42,7 +42,6 @@ compute_SpecAbundAve <- function(ramclustObj = NULL) {
 #' @param hmax numeric: precut the tree at this height, default 0.3 - see ?cutreeDynamicTree
 #' @param sampNameCol integer: which column from the csv file contains sample names?
 #' @param collapse logical: reduce feature intensities to spectrum intensities?
-#' @param usePheno logical: transfer phenotype data from XCMS object to SpecAbund dataset?
 #' @param mspout logical: write msp formatted spectra to file?
 #' @param ExpDes either an R object created by R ExpDes object: data used for record keeping and labelling msp spectral output
 #' @param normalize character: either "none", "TIC", "quantile", or "batch.qc" normalization of feature intensities.  see batch.qc overview in details.
@@ -55,7 +54,6 @@ compute_SpecAbundAve <- function(ramclustObj = NULL) {
 #' @param mzdec integer: number of decimal places used in printing m/z values
 #' @param cor.method character: which correlational method used to calculate 'r' - see ?cor
 #' @param rt.only.low.n logical: default = TRUE  At low injection numbers, correlational relationships of peak intensities may be unreliable.  by defualt ramclustR will simply ignore the correlational r value and cluster on retention time alone.  if you wish to use correlation with at n < 5, set this value to FALSE.
-#' @param fftempdir valid path: if there are file size limitations on the default ff package temp directory  - getOptions('fftempdir') - you can change the directory used as the fftempdir with this option.
 #' @param replace.zeros logical: TRUE by default.  NA, NaN, and Inf values are replaced with zero, and zero values are sometimes returned from peak peaking.  When TRUE, zero values will be replaced with a small amount of noise, with noise level set based on the detected signal intensities for that feature.
 #' @details Main clustering function output - see citation for algorithm description or vignette('RAMClustR') for a walk through.  batch.qc. normalization requires input of three vectors (1) batch (2) order (3) qc.   This is a feature centric normalization approach which adjusts signal intensities first by comparing batch median intensity of each feature (one feature at a time) QC signal intensity to full dataset median to correct for systematic batch effects and then secondly to apply a local QC median vs global median sample correction to correct for run order effects.
 #' @return   $featclus: integer vector of cluster membership for each feature
@@ -78,14 +76,12 @@ compute_SpecAbundAve <- function(ramclustObj = NULL) {
 #' @importFrom graphics abline axis boxplot hist "legend" "par" "plot" "points" "title"
 #' @importFrom stats aggregate cor fitted lm loess median predict quantile sd weighted.mean
 #' @importFrom utils edit read.csv read.delim read.delim2 write.csv packageVersion
-#' @importFrom ff ff
 #' @importFrom fastcluster hclust
 #' @importFrom dynamicTreeCut cutreeDynamicTree
 #' @importFrom e1071 skewness
 #' @importFrom gplots heatmap.2
 #' @importFrom pcaMethods pca
 #' @importFrom jsonlite fromJSON
-#' @importFrom preprocessCore normalize.quantiles
 #' @importFrom utils citation packageVersion
 #'
 #' @references Broeckling CD, Afsar FA, Neumann S, Ben-Hur A, Prenni JE. RAMClust: a novel feature clustering method enables spectral-matching-based annotation for metabolomics data. Anal Chem. 2014 Jul 15;86(14):6812-7. doi: 10.1021/ac501530d.  Epub 2014 Jun 26. PubMed PMID: 24927477.
@@ -141,7 +137,6 @@ ramclustR <- function(xcmsObj = NULL,
                       hmax = NULL,
                       sampNameCol = 1,
                       collapse = TRUE,
-                      usePheno = TRUE,
                       mspout = TRUE,
                       ExpDes = NULL,
                       normalize = "TIC",
@@ -154,7 +149,6 @@ ramclustR <- function(xcmsObj = NULL,
                       mzdec = 3,
                       cor.method = "pearson",
                       rt.only.low.n = TRUE,
-                      fftempdir = NULL,
                       replace.zeros = TRUE) {
   ########
   # If experimental design is NULL:
@@ -176,11 +170,6 @@ ramclustR <- function(xcmsObj = NULL,
     }
   }
 
-  if (!is.null(fftempdir)) {
-    origffdir <- getOption("fftempdir")
-    options("fftempdir" = fftempdir)
-  }
-
   ########
   # define ms levels, used several times below
   mslev <- as.integer(as.numeric(as.character(ExpDes[[2]][which(row.names(ExpDes[[2]]) == "MSlevs"), 1])))
@@ -306,6 +295,9 @@ ramclustR <- function(xcmsObj = NULL,
   if (normalize == "batch.qc") {
     ramclustObj <- rc.feature.normalize.batch.qc(
       ramclustObj = ramclustObj,
+      batch = batch,
+      order = order,
+      qc = qc,
       qc.inj.range = qc.inj.range
     )
 
@@ -327,8 +319,7 @@ ramclustR <- function(xcmsObj = NULL,
     minModuleSize = minModuleSize,
     linkage = linkage,
     cor.method = cor.method,
-    rt.only.low.n = rt.only.low.n,
-    fftempdir = fftempdir
+    rt.only.low.n = rt.only.low.n
   )
 
   history <- paste(
