@@ -1,3 +1,17 @@
+quantile_normalisation <- function(df) {
+    df_rank <- apply(df, 2, rank, ties.method = "min")
+    df_sorted <- data.frame(apply(df, 2, sort))
+    df_mean <- apply(df_sorted, 1, mean)
+
+    index_to_mean <- function(my_index, my_mean) {
+        return(my_mean[my_index])
+    }
+
+    df_final <- apply(df_rank, 2, index_to_mean, my_mean = df_mean)
+    rownames(df_final) <- rownames(df)
+    return(df_final)
+}
+
 #' rc.feature.normalize.quantile
 #'
 #' normalize data using quantile
@@ -5,16 +19,11 @@
 #' @param ramclustObj ramclustObj containing MSdata with optional MSMSdata (MSe, DIA, idMSMS)
 #' @return  ramclustR object with normalized data.
 #' @export
-
 rc.feature.normalize.quantile <- function(ramclustObj = NULL) {
-    tmpnames1 <- dimnames(ramclustObj$MSdata)
-    ramclustObj$MSdata <- t(preprocessCore::normalize.quantiles(t(ramclustObj$MSdata)))
-    dimnames(ramclustObj$MSdata) <- tmpnames1
+    ramclustObj$MSdata <- t(quantile_normalisation(t(ramclustObj$MSdata)))
 
     if (!is.null(ramclustObj$MSMSdata)) {
-        tmpnames2 <- dimnames(ramclustObj$MSMSdata)
-        ramclustObj$MSMSdata <- t(preprocessCore::normalize.quantiles(t(ramclustObj$MSMSdata)))
-        dimnames(ramclustObj$MSMSdata) <- tmpnames2
+        ramclustObj$MSMSdata <- t(quantile_normalisation(t(ramclustObj$MSMSdata)))
     }
 
     ## update msint and optionally msmsint
