@@ -5,13 +5,19 @@ test_that("RAMClustR workflow with xcms works", {
   tmp <- tempdir()
   load(file.path("testdata", "test.fillpeaks"))
   expected <- readRDS(file.path("testdata", "do.findmain.rds"))
+  metadata <- read_metadata(file.path("testdata", "testMetadata.csv"))
   setwd(tmp)
 
   ramclustObj <- rc.get.xcms.data(xcmsObj = xdata)
-  ramclustObj <- rc.expand.sample.names(ramclustObj = ramclustObj, quiet=TRUE)
+  ramclustObj <- rc.expand.sample.names(ramclustObj = ramclustObj, quiet = TRUE)
   ramclustObj <- rc.feature.replace.na(ramclustObj = ramclustObj)
   ramclustObj <- rc.feature.filter.blanks(ramclustObj = ramclustObj, blank.tag = "Blanc")
-  ramclustObj <- rc.feature.normalize.qc(ramclustObj = ramclustObj, qc.tag = "QC")
+  ramclustObj <- rc.feature.normalize.qc(
+    ramclustObj = ramclustObj,
+    batch = metadata$batch,
+    order = metadata$order,
+    qc = metadata$qc
+  )
   ramclustObj <- rc.feature.filter.cv(ramclustObj = ramclustObj)
   ramclustObj <- rc.ramclustr(ramclustObj = ramclustObj)
   ramclustObj <- rc.qc(ramclustObj = ramclustObj)
@@ -22,6 +28,8 @@ test_that("RAMClustR workflow with xcms works", {
 
   actual$history <- NA
   expected$history <- NA
+  actual$params$rc.feature.normalize.qc <- NA
+  expected$params$rc.feature.normalize.qc <- NA
 
   expect_equal(actual, expected)
 
