@@ -1,15 +1,18 @@
 test_that("RAMClustR with xcms works", {
   skip_if_not_installed("xcms")
+  set.seed(123) # to get reproducible results with jitters
   wd <- getwd()
   tmp <- tempdir()
-  load("testdata/test.fillpeaks")
-  expected <- readLines("testdata/output.msp")
-
+  load(file.path("testdata", "test.fillpeaks"))
+  expected <- readLines(file.path("testdata", "output.msp"))
+  
   setwd(tmp)
-  ramclustr_obj <- ramclustR(xcmsObj = xdata)
+
+  ramclustr_obj <- ramclustR(xcmsObj = xdata, maxt = 20, sr = 0.5, mzdec = 4)
   write.msp(ramclustr_obj, one.file = TRUE)
-  diff <- setdiff(expected, readLines("spectra/fill.msp"))
-  expect_true(length(diff) < 10)
+  mismatches <- setdiff(expected, readLines(file.path("spectra", "fill.msp")))
+  
+  expect_true(length(mismatches) < 10)
   setwd(wd)
 })
 
@@ -17,10 +20,18 @@ test_that("RAMClustR with csv works", {
   wd <- getwd()
   tmp <- tempdir()
   filename <- file.path(wd, "testdata/peaks.csv")
-  expected <- readRDS("testdata/ramclustObj.rds")
-
+  pheno <- file.path(wd, "testdata/phenoData.csv")
+  expected <- readRDS(file.path("testdata", "test_csv.rds"))
+  
   setwd(tmp)
-  actual <- ramclustR(ms = filename, st = 5, maxt = 1, blocksize = 1000)
+  actual <- ramclustR(
+    ms = filename,
+    pheno_csv = pheno,
+    st = 5,
+    maxt = 1,
+    blocksize = 1000
+  )
+
   actual$history <- NA
   expected$history <- NA
 
